# TimeIntervalMetrics

Metrics for a time interval
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**time** | **datetime** | Beginning of the interval for which the metrics were retrieved | [optional] [readonly] 
**metric** | **int** | Retrieved metric (e.g. number of active users) | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


